--------------------------------------------------------------------------------
--
--  Top-level VHDL Entity for WR Switch V4 (HWv1)
--
--------------------------------------------------------------------------------
--
--  Copyright CERN 2020.
--
--  This source describes Open Hardware and is licensed under the CERN-OHLW v2
--  or later
--
--  You may redistribute and modify this documentation and make products
--  using it under the terms of the CERN-OHL-W v2 (https:/cern.ch/cern-ohl).
--  This documentation is distributed WITHOUT ANY EXPRESS OR IMPLIED
--  WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY
--  AND FITNESS FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-W v2
--  for applicable conditions.
--
--  Source location: https://ohwr.org/project/wr-switch-hw-v4
--
--  As per CERN-OHL-W v2 section 4.1, should You produce hardware based on
--  these sources, You must maintain the Source Location visible on the
--  external case of the White Rabbit switch or other product you make using
--  this documentation.
--
--------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.all;

entity WRSv4_topEntity is
port (
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RT_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RT_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RT_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RCT_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RCT_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RCT_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RCB_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RCB_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RCB_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RB_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RB_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_RB_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LT_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LT_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LT_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LCT_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LCT_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LCT_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LCB_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LCB_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LCB_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LB_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LB_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_2_PL_LB_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RT_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RT_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RT_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RCT_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RCT_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RCT_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RCB_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RCB_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RCB_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RB_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RB_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_RB_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LT_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LT_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LT_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LCT_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LCT_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LCT_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LCB_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LCB_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LCB_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LB_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LB_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_1_PL_LB_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RT_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RT_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RT_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RCT_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RCT_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RCT_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RCB_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RCB_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RCB_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RB_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RB_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_RB_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LT_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LT_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LT_SFP_DETECT      : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LCT_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LCT_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LCT_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LCB_SFP_TX_FAULT   : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LCB_SFP_TX_DISABLE : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LCB_SFP_DETECT     : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LB_SFP_TX_FAULT    : in  std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LB_SFP_TX_DISABLE  : out std_logic;
  SFPPLUS_4x2_P1V8_CTRL_0_PL_LB_SFP_DETECT      : in  std_logic;

  PWR_CTRL_FMC_PWR_EN : out std_logic;
  PWR_CTRL_FMC_PG     : in  std_logic;

  PPS_CTRL_TERM_EN : out std_logic;

  PPS_CTRL_PPS_OUT : out std_logic;
  PPS_CTRL_AUX_OUT : out std_logic;

  PLL_GM_P1V8_CTRL_PLL_GM_SYNC : out std_logic;
  PLL_GM_P1V8_CTRL_PLL_GM_SDI  : out std_logic;
  PLL_GM_P1V8_CTRL_PLL_GM_SCK  : out std_logic;
  PLL_GM_P1V8_CTRL_PLL_GM_CSB  : out std_logic;

  PB10 : in std_logic;
  PB09 : in std_logic;

  PLL_OSCOUT1_CLK_N : in std_logic;
  PLL_OSCOUT1_CLK_P : in std_logic;

  REF_CLK_N : in std_logic;
  REF_CLK_P : in std_logic;

  WR_CLK_N : in std_logic;
  WR_CLK_P : in std_logic;

  LMX_GM_CLK_CLK_P : in std_logic;
  LMX_GM_CLK_CLK_N : in std_logic;

  LED_SFP_4x2_CTRL_2_RT_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_2_RT_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_2_RT_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_2_RT_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_2_RCT_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_2_RCT_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_2_RCT_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_2_RCT_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_2_RCB_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_2_RCB_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_2_RCB_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_2_RCB_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_2_RB_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_2_RB_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_2_RB_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_2_RB_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_2_LT_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_2_LT_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_2_LT_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_2_LT_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_2_LCT_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_2_LCT_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_2_LCT_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_2_LCT_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_2_LCB_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_2_LCB_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_2_LCB_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_2_LCB_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_2_LB_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_2_LB_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_2_LB_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_2_LB_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_1_RT_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_1_RT_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_1_RT_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_1_RT_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_1_RCT_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_1_RCT_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_1_RCT_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_1_RCT_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_1_RCB_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_1_RCB_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_1_RCB_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_1_RCB_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_1_RB_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_1_RB_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_1_RB_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_1_RB_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_1_LT_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_1_LT_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_1_LT_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_1_LT_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_1_LCT_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_1_LCT_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_1_LCT_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_1_LCT_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_1_LCB_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_1_LCB_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_1_LCB_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_1_LCB_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_1_LB_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_1_LB_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_1_LB_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_1_LB_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_0_RT_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_0_RT_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_0_RT_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_0_RT_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_0_RCT_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_0_RCT_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_0_RCT_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_0_RCT_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_0_RCB_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_0_RCB_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_0_RCB_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_0_RCB_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_0_RB_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_0_RB_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_0_RB_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_0_RB_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_0_LT_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_0_LT_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_0_LT_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_0_LT_SFP_LED_ACTIVITY  : out std_logic;
  LED_SFP_4x2_CTRL_0_LCT_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_0_LCT_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_0_LCT_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_0_LCT_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_0_LCB_SFP_LED_SYNCED   : out std_logic;
  LED_SFP_4x2_CTRL_0_LCB_SFP_LED_MODE     : out std_logic;
  LED_SFP_4x2_CTRL_0_LCB_SFP_LED_LINK     : out std_logic;
  LED_SFP_4x2_CTRL_0_LCB_SFP_LED_ACTIVITY : out std_logic;
  LED_SFP_4x2_CTRL_0_LB_SFP_LED_SYNCED    : out std_logic;
  LED_SFP_4x2_CTRL_0_LB_SFP_LED_MODE      : out std_logic;
  LED_SFP_4x2_CTRL_0_LB_SFP_LED_LINK      : out std_logic;
  LED_SFP_4x2_CTRL_0_LB_SFP_LED_ACTIVITY  : out std_logic;

  LCD_BButton_2 : in std_logic;
  LCD_BButton_1 : in std_logic;

  -- MB: FMC LA pins can be either input or output depending on FMC
  -- but safer to define them as input whilist uncommitted. 
  LA33_P : in std_logic;
  LA33_N : in std_logic;
  LA32_P : in std_logic;
  LA32_N : in std_logic;
  LA31_P : in std_logic;
  LA31_N : in std_logic;
  LA30_P : in std_logic;
  LA30_N : in std_logic;
  LA29_P : in std_logic;
  LA29_N : in std_logic;
  LA28_P : in std_logic;
  LA28_N : in std_logic;
  LA27_P : in std_logic;
  LA27_N : in std_logic;
  LA26_P : in std_logic;
  LA26_N : in std_logic;
  LA25_P : in std_logic;
  LA25_N : in std_logic;
  LA24_P : in std_logic;
  LA24_N : in std_logic;
  LA23_P : in std_logic;
  LA23_N : in std_logic;
  LA22_P : in std_logic;
  LA22_N : in std_logic;
  LA21_P : in std_logic;
  LA21_N : in std_logic;
  LA20_P : in std_logic;
  LA20_N : in std_logic;
  LA19_P : in std_logic;
  LA19_N : in std_logic;
  LA18_CC_P : in std_logic;
  LA18_CC_N : in std_logic;
  LA17_CC_P : in std_logic;
  LA17_CC_N : in std_logic;
  LA16_P : in std_logic;
  LA16_N : in std_logic;
  LA15_P : in std_logic;
  LA15_N : in std_logic;
  LA14_P : in std_logic;
  LA14_N : in std_logic;
  LA13_P : in std_logic;
  LA13_N : in std_logic;
  LA12_P : in std_logic;
  LA12_N : in std_logic;
  LA11_P : in std_logic;
  LA11_N : in std_logic;
  LA10_P : in std_logic;
  LA10_N : in std_logic;
  LA09_P : in std_logic;
  LA09_N : in std_logic;
  LA08_P : in std_logic;
  LA08_N : in std_logic;
  LA07_P : in std_logic;
  LA07_N : in std_logic;
  LA06_P : in std_logic;
  LA06_N : in std_logic;
  LA05_P : in std_logic;
  LA05_N : in std_logic;
  LA04_P : in std_logic;
  LA04_N : in std_logic;
  LA03_P : in std_logic;
  LA03_N : in std_logic;
  LA02_P : in std_logic;
  LA02_N : in std_logic;
  LA01_CC_P : in std_logic;
  LA01_CC_N : in std_logic;
  LA00_CC_P : in std_logic;
  LA00_CC_N : in std_logic;

  HMC_P1V8_CTRL_HMC_SYNC  : out   std_logic;
  HMC_P1V8_CTRL_HMC_SLEN  : out   std_logic;
  HMC_P1V8_CTRL_HMC_SDATA : inout std_logic;
  HMC_P1V8_CTRL_HMC_SCLK  : out   std_logic;
  HMC_P1V8_CTRL_HMC_RESET : out   std_logic;

  HELPER_CLK_CLK_P : in std_logic;
  HELPER_CLK_CLK_N : in std_logic;

  GTY131_CLK0_P : in std_logic;
  GTY131_CLK0_N : in std_logic;
  GTY130_CLK0_P : in std_logic;
  GTY130_CLK0_N : in std_logic;
  GTY129_CLK0_P : in std_logic;
  GTY129_CLK0_N : in std_logic;
  GTY128_CLK0_P : in std_logic;
  GTY128_CLK0_N : in std_logic;


  GTH_229_TXRX_GTH_TX3_P : out std_logic;
  GTH_229_TXRX_GTH_TX3_N : out std_logic;
  GTH_229_TXRX_GTH_TX2_P : out std_logic;
  GTH_229_TXRX_GTH_TX2_N : out std_logic;
  GTH_229_TXRX_GTH_TX1_P : out std_logic;
  GTH_229_TXRX_GTH_TX1_N : out std_logic;
  GTH_229_TXRX_GTH_TX0_P : out std_logic;
  GTH_229_TXRX_GTH_TX0_N : out std_logic;
  GTH_229_TXRX_GTH_RX3_P : in  std_logic;
  GTH_229_TXRX_GTH_RX3_N : in  std_logic;
  GTH_229_TXRX_GTH_RX2_P : in  std_logic;
  GTH_229_TXRX_GTH_RX2_N : in  std_logic;
  GTH_229_TXRX_GTH_RX1_P : in  std_logic;
  GTH_229_TXRX_GTH_RX1_N : in  std_logic;
  GTH_229_TXRX_GTH_RX0_P : in  std_logic;
  GTH_229_TXRX_GTH_RX0_N : in  std_logic;

  GTH_228_TXRX_GTH_TX3_P : out std_logic;
  GTH_228_TXRX_GTH_TX3_N : out std_logic;
  GTH_228_TXRX_GTH_TX2_P : out std_logic;
  GTH_228_TXRX_GTH_TX2_N : out std_logic;
  GTH_228_TXRX_GTH_TX1_P : out std_logic;
  GTH_228_TXRX_GTH_TX1_N : out std_logic;
  GTH_228_TXRX_GTH_TX0_P : out std_logic;
  GTH_228_TXRX_GTH_TX0_N : out std_logic;
  GTH_228_TXRX_GTH_RX3_P : in  std_logic;
  GTH_228_TXRX_GTH_RX3_N : in  std_logic;
  GTH_228_TXRX_GTH_RX2_P : in  std_logic;
  GTH_228_TXRX_GTH_RX2_N : in  std_logic;
  GTH_228_TXRX_GTH_RX1_P : in  std_logic;
  GTH_228_TXRX_GTH_RX1_N : in  std_logic;
  GTH_228_TXRX_GTH_RX0_P : in  std_logic;
  GTH_228_TXRX_GTH_RX0_N : in  std_logic;

  GTH_227_TXRX_GTH_TX3_P : out std_logic;
  GTH_227_TXRX_GTH_TX3_N : out std_logic;
  GTH_227_TXRX_GTH_TX2_P : out std_logic;
  GTH_227_TXRX_GTH_TX2_N : out std_logic;
  GTH_227_TXRX_GTH_TX1_P : out std_logic;
  GTH_227_TXRX_GTH_TX1_N : out std_logic;
  GTH_227_TXRX_GTH_TX0_P : out std_logic;
  GTH_227_TXRX_GTH_TX0_N : out std_logic;
  GTH_227_TXRX_GTH_RX3_P : in  std_logic;
  GTH_227_TXRX_GTH_RX3_N : in  std_logic;
  GTH_227_TXRX_GTH_RX2_P : in  std_logic;
  GTH_227_TXRX_GTH_RX2_N : in  std_logic;
  GTH_227_TXRX_GTH_RX1_P : in  std_logic;
  GTH_227_TXRX_GTH_RX1_N : in  std_logic;
  GTH_227_TXRX_GTH_RX0_P : in  std_logic;
  GTH_227_TXRX_GTH_RX0_N : in  std_logic;

  GTH_226_TXRX_GTH_TX3_P : out std_logic;
  GTH_226_TXRX_GTH_TX3_N : out std_logic;
  GTH_226_TXRX_GTH_TX2_P : out std_logic;
  GTH_226_TXRX_GTH_TX2_N : out std_logic;
  GTH_226_TXRX_GTH_TX1_P : out std_logic;
  GTH_226_TXRX_GTH_TX1_N : out std_logic;
  GTH_226_TXRX_GTH_TX0_P : out std_logic;
  GTH_226_TXRX_GTH_TX0_N : out std_logic;
  GTH_226_TXRX_GTH_RX3_P : in  std_logic;
  GTH_226_TXRX_GTH_RX3_N : in  std_logic;
  GTH_226_TXRX_GTH_RX2_P : in  std_logic;
  GTH_226_TXRX_GTH_RX2_N : in  std_logic;
  GTH_226_TXRX_GTH_RX1_P : in  std_logic;
  GTH_226_TXRX_GTH_RX1_N : in  std_logic;
  GTH_226_TXRX_GTH_RX0_P : in  std_logic;
  GTH_226_TXRX_GTH_RX0_N : in  std_logic;

  GTH_225_TXRX_GTH_TX3_P : out std_logic;
  GTH_225_TXRX_GTH_TX3_N : out std_logic;
  GTH_225_TXRX_GTH_TX2_P : out std_logic;
  GTH_225_TXRX_GTH_TX2_N : out std_logic;
  GTH_225_TXRX_GTH_TX1_P : out std_logic;
  GTH_225_TXRX_GTH_TX1_N : out std_logic;
  GTH_225_TXRX_GTH_TX0_P : out std_logic;
  GTH_225_TXRX_GTH_TX0_N : out std_logic;
  GTH_225_TXRX_GTH_RX3_P : in  std_logic;
  GTH_225_TXRX_GTH_RX3_N : in  std_logic;
  GTH_225_TXRX_GTH_RX2_P : in  std_logic;
  GTH_225_TXRX_GTH_RX2_N : in  std_logic;
  GTH_225_TXRX_GTH_RX1_P : in  std_logic;
  GTH_225_TXRX_GTH_RX1_N : in  std_logic;
  GTH_225_TXRX_GTH_RX0_P : in  std_logic;
  GTH_225_TXRX_GTH_RX0_N : in  std_logic;

  GTH_224_TXRX_GTH_TX3_P : out std_logic;
  GTH_224_TXRX_GTH_TX3_N : out std_logic;
  GTH_224_TXRX_GTH_TX2_P : out std_logic;
  GTH_224_TXRX_GTH_TX2_N : out std_logic;
  GTH_224_TXRX_GTH_TX1_P : out std_logic;
  GTH_224_TXRX_GTH_TX1_N : out std_logic;
  GTH_224_TXRX_GTH_TX0_P : out std_logic;
  GTH_224_TXRX_GTH_TX0_N : out std_logic;
  GTH_224_TXRX_GTH_RX3_P : in  std_logic;
  GTH_224_TXRX_GTH_RX3_N : in  std_logic;
  GTH_224_TXRX_GTH_RX2_P : in  std_logic;
  GTH_224_TXRX_GTH_RX2_N : in  std_logic;
  GTH_224_TXRX_GTH_RX1_P : in  std_logic;
  GTH_224_TXRX_GTH_RX1_N : in  std_logic;
  GTH_224_TXRX_GTH_RX0_P : in  std_logic;
  GTH_224_TXRX_GTH_RX0_N : in  std_logic;

  GTH231_TX3_P : out std_logic;
  GTH231_TX3_N : out std_logic;
  GTH231_TX2_P : out std_logic;
  GTH231_TX2_N : out std_logic;
  GTH231_TX1_P : out std_logic;
  GTH231_TX1_N : out std_logic;
  GTH231_TX0_P : out std_logic;
  GTH231_TX0_N : out std_logic;
  GTH231_RX3_P : in  std_logic;
  GTH231_RX3_N : in  std_logic;
  GTH231_RX2_P : in  std_logic;
  GTH231_RX2_N : in  std_logic;
  GTH231_RX1_P : in  std_logic;
  GTH231_RX1_N : in  std_logic;
  GTH231_RX0_P : in  std_logic;
  GTH231_RX0_N : in  std_logic;

  GTH231_CLK1_P : in std_logic;
  GTH231_CLK1_N : in std_logic;
  GTH231_CLK0_P : in std_logic;
  GTH231_CLK0_N : in std_logic;
  GTH230_CLK1_P : in std_logic;
  GTH230_CLK1_N : in std_logic;
  GTH230_CLK0_P : in std_logic;
  GTH230_CLK0_N : in std_logic;
  GTH229_CLK1_P : in std_logic;
  GTH229_CLK1_N : in std_logic;
  GTH229_CLK0_P : in std_logic;
  GTH229_CLK0_N : in std_logic;
  GTH228_CLK1_P : in std_logic;
  GTH228_CLK1_N : in std_logic;
  GTH228_CLK0_P : in std_logic;
  GTH228_CLK0_N : in std_logic;
  GTH227_CLK1_P : in std_logic;
  GTH227_CLK1_N : in std_logic;
  GTH227_CLK0_P : in std_logic;
  GTH227_CLK0_N : in std_logic;
  GTH226_CLK1_P : in std_logic;
  GTH226_CLK1_N : in std_logic;
  GTH226_CLK0_P : in std_logic;
  GTH226_CLK0_N : in std_logic;
  GTH225_CLK1_P : in std_logic;
  GTH225_CLK1_N : in std_logic;
  GTH225_CLK0_P : in std_logic;
  GTH225_CLK0_N : in std_logic;
  GTH224_CLK1_P : in std_logic;
  GTH224_CLK1_N : in std_logic;
  GTH224_CLK0_P : in std_logic;
  GTH224_CLK0_N : in std_logic;

  FAN_PRESENT_FAN2_PRESENT : in std_logic;
  FAN_PRESENT_FAN1_PRESENT : in std_logic;

  EXT_GM_CLK_CLK_P : in std_logic;
  EXT_GM_CLK_CLK_N : in std_logic;

  DP16_DP19_TXRX_GTH_TX3_P : out std_logic;
  DP16_DP19_TXRX_GTH_TX3_N : out std_logic;
  DP16_DP19_TXRX_GTH_TX2_P : out std_logic;
  DP16_DP19_TXRX_GTH_TX2_N : out std_logic;
  DP16_DP19_TXRX_GTH_TX1_P : out std_logic;
  DP16_DP19_TXRX_GTH_TX1_N : out std_logic;
  DP16_DP19_TXRX_GTH_TX0_P : out std_logic;
  DP16_DP19_TXRX_GTH_TX0_N : out std_logic;
  DP16_DP19_TXRX_GTH_RX3_P : in  std_logic;
  DP16_DP19_TXRX_GTH_RX3_N : in  std_logic;
  DP16_DP19_TXRX_GTH_RX2_P : in  std_logic;
  DP16_DP19_TXRX_GTH_RX2_N : in  std_logic;
  DP16_DP19_TXRX_GTH_RX1_P : in  std_logic;
  DP16_DP19_TXRX_GTH_RX1_N : in  std_logic;
  DP16_DP19_TXRX_GTH_RX0_P : in  std_logic;
  DP16_DP19_TXRX_GTH_RX0_N : in  std_logic;

  DP12_DP15_TXRX_GTY_TX3_P : out std_logic;
  DP12_DP15_TXRX_GTY_TX3_N : out std_logic;
  DP12_DP15_TXRX_GTY_TX2_P : out std_logic;
  DP12_DP15_TXRX_GTY_TX2_N : out std_logic;
  DP12_DP15_TXRX_GTY_TX1_P : out std_logic;
  DP12_DP15_TXRX_GTY_TX1_N : out std_logic;
  DP12_DP15_TXRX_GTY_TX0_P : out std_logic;
  DP12_DP15_TXRX_GTY_TX0_N : out std_logic;
  DP12_DP15_TXRX_GTY_RX3_P : in  std_logic;
  DP12_DP15_TXRX_GTY_RX3_N : in  std_logic;
  DP12_DP15_TXRX_GTY_RX2_P : in  std_logic;
  DP12_DP15_TXRX_GTY_RX2_N : in  std_logic;
  DP12_DP15_TXRX_GTY_RX1_P : in  std_logic;
  DP12_DP15_TXRX_GTY_RX1_N : in  std_logic;
  DP12_DP15_TXRX_GTY_RX0_P : in  std_logic;
  DP12_DP15_TXRX_GTY_RX0_N : in  std_logic;
  DP12_DP15_TXRX_GTY_CLK_P : in  std_logic;
  DP12_DP15_TXRX_GTY_CLK_N : in  std_logic;

  DP8_DP11_TXRX_GTY_TX3_P : out std_logic;
  DP8_DP11_TXRX_GTY_TX3_N : out std_logic;
  DP8_DP11_TXRX_GTY_TX2_P : out std_logic;
  DP8_DP11_TXRX_GTY_TX2_N : out std_logic;
  DP8_DP11_TXRX_GTY_TX1_P : out std_logic;
  DP8_DP11_TXRX_GTY_TX1_N : out std_logic;
  DP8_DP11_TXRX_GTY_TX0_P : out std_logic;
  DP8_DP11_TXRX_GTY_TX0_N : out std_logic;
  DP8_DP11_TXRX_GTY_RX3_P : in  std_logic;
  DP8_DP11_TXRX_GTY_RX3_N : in  std_logic;
  DP8_DP11_TXRX_GTY_RX2_P : in  std_logic;
  DP8_DP11_TXRX_GTY_RX2_N : in  std_logic;
  DP8_DP11_TXRX_GTY_RX1_P : in  std_logic;
  DP8_DP11_TXRX_GTY_RX1_N : in  std_logic;
  DP8_DP11_TXRX_GTY_RX0_P : in  std_logic;
  DP8_DP11_TXRX_GTY_RX0_N : in  std_logic;
  DP8_DP11_TXRX_GTY_CLK_P : in std_logic;
  DP8_DP11_TXRX_GTY_CLK_N : in std_logic;

  DP4_DP7_TXRX_GTY_TX3_P : out std_logic;
  DP4_DP7_TXRX_GTY_TX3_N : out std_logic;
  DP4_DP7_TXRX_GTY_TX2_P : out std_logic;
  DP4_DP7_TXRX_GTY_TX2_N : out std_logic;
  DP4_DP7_TXRX_GTY_TX1_P : out std_logic;
  DP4_DP7_TXRX_GTY_TX1_N : out std_logic;
  DP4_DP7_TXRX_GTY_TX0_P : out std_logic;
  DP4_DP7_TXRX_GTY_TX0_N : out std_logic;
  DP4_DP7_TXRX_GTY_RX3_P : in  std_logic;
  DP4_DP7_TXRX_GTY_RX3_N : in  std_logic;
  DP4_DP7_TXRX_GTY_RX2_P : in  std_logic;
  DP4_DP7_TXRX_GTY_RX2_N : in  std_logic;
  DP4_DP7_TXRX_GTY_RX1_P : in  std_logic;
  DP4_DP7_TXRX_GTY_RX1_N : in  std_logic;
  DP4_DP7_TXRX_GTY_RX0_P : in  std_logic;
  DP4_DP7_TXRX_GTY_RX0_N : in  std_logic;
  DP4_DP7_TXRX_GTY_CLK_P : in std_logic;
  DP4_DP7_TXRX_GTY_CLK_N : in std_logic;

  DP0_DP3_TXRX_GTY_TX3_P : out std_logic;
  DP0_DP3_TXRX_GTY_TX3_N : out std_logic;
  DP0_DP3_TXRX_GTY_TX2_P : out std_logic;
  DP0_DP3_TXRX_GTY_TX2_N : out std_logic;
  DP0_DP3_TXRX_GTY_TX1_P : out std_logic;
  DP0_DP3_TXRX_GTY_TX1_N : out std_logic;
  DP0_DP3_TXRX_GTY_TX0_P : out std_logic;
  DP0_DP3_TXRX_GTY_TX0_N : out std_logic;
  DP0_DP3_TXRX_GTY_RX3_P : in  std_logic;
  DP0_DP3_TXRX_GTY_RX3_N : in  std_logic;
  DP0_DP3_TXRX_GTY_RX2_P : in  std_logic;
  DP0_DP3_TXRX_GTY_RX2_N : in  std_logic;
  DP0_DP3_TXRX_GTY_RX1_P : in  std_logic;
  DP0_DP3_TXRX_GTY_RX1_N : in  std_logic;
  DP0_DP3_TXRX_GTY_RX0_P : in  std_logic;
  DP0_DP3_TXRX_GTY_RX0_N : in  std_logic;
  DP0_DP3_TXRX_GTY_CLK_P : in std_logic;
  DP0_DP3_TXRX_GTY_CLK_N : in std_logic;

  CLK1_M2C_P : in std_logic;
  CLK1_M2C_N : in std_logic;
  CLK0_M2C_P : in std_logic;
  CLK0_M2C_N : in std_logic;

  AUX_CLK_IN_CLK_P : in std_logic;
  AUX_CLK_IN_CLK_N : in std_logic;

  AUX_CLK_CLK_P : in std_logic;
  AUX_CLK_CLK_N : in std_logic;

  D10MHz_M_P : in std_logic;
  D10MHz_M_N : in std_logic;

  PPS_IN : in std_logic;

  GM_PWR_EN : out std_logic;

  CLK_10MHz_OUT_SEL : out std_logic;

  GTH_CLK1_SEL : out std_logic;

  PLL_GM_RAMPDIR   : out std_logic;
  PLL_GM_RAMPCLK   : out std_logic;
  PLL_GM_MUXOUT    : in  std_logic;
  PLL_GM_SYSREFREQ : out std_logic;

  HMC_GPIO1 : inout std_logic;
  HMC_GPIO2 : inout std_logic;
  HMC_GPIO3 : inout std_logic;
  HMC_GPIO4 : inout std_logic;

  PLL_CLK_SEL : out std_logic;

  DAC_SYNC_N : out std_logic;
  DAC_DIN    : out std_logic;
  DAC_SCLK   : out std_logic;

  PL_UART_RX : in  std_logic;
  PL_UART_TX : out std_logic;

  SCL_AUX : out   std_logic;
  SDA_AUX : inout std_logic;

  SCL_HELPER : out   std_logic;
  SDA_HELPER : inout std_logic;

  PRSNT_M2C_L : in std_logic;
  PG_M2C      : in std_logic;

  SFPPLUS_4x2_I2C_2_RB_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_2_RB_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_2_RCT_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_2_RCT_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_2_RCB_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_2_RCB_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_2_RT_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_2_RT_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_2_LB_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_2_LB_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_2_LT_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_2_LT_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_2_LCT_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_2_LCT_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_2_LCB_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_2_LCB_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_1_RB_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_1_RB_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_1_RCT_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_1_RCT_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_1_RCB_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_1_RCB_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_1_RT_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_1_RT_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_1_LB_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_1_LB_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_1_LT_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_1_LT_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_1_LCT_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_1_LCT_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_1_LCB_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_1_LCB_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_0_RB_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_0_RB_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_0_RCT_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_0_RCT_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_0_RCB_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_0_RCB_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_0_RT_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_0_RT_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_0_LB_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_0_LB_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_0_LT_SFP_SDA  : inout std_logic;
  SFPPLUS_4x2_I2C_0_LT_SFP_SCL  : out   std_logic;
  SFPPLUS_4x2_I2C_0_LCT_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_0_LCT_SFP_SCL : out   std_logic;
  SFPPLUS_4x2_I2C_0_LCB_SFP_SDA : inout std_logic;
  SFPPLUS_4x2_I2C_0_LCB_SFP_SCL : out   std_logic;

  SFPPLUS_4x2_LOS_2_LT_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_2_RCB_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_2_LB_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_2_RB_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_2_LCB_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_2_LCT_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_2_RCT_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_2_RT_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_1_LT_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_1_RCB_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_1_LB_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_1_RB_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_1_LCB_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_1_LCT_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_1_RCT_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_1_RT_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_0_LT_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_0_RCB_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_0_LB_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_0_RB_SFP_LOS  : in std_logic;
  SFPPLUS_4x2_LOS_0_LCB_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_0_LCT_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_0_RCT_SFP_LOS : in std_logic;
  SFPPLUS_4x2_LOS_0_RT_SFP_LOS  : in std_logic
);
attribute io_buffer_type : string;
attribute io_buffer_type of GTH_229_TXRX_GTH_TX3_P   : signal is "none";
attribute io_buffer_type of GTH_229_TXRX_GTH_TX3_N   : signal is "none";
attribute io_buffer_type of GTH_229_TXRX_GTH_TX2_P   : signal is "none";
attribute io_buffer_type of GTH_229_TXRX_GTH_TX2_N   : signal is "none";
attribute io_buffer_type of GTH_229_TXRX_GTH_TX1_P   : signal is "none";
attribute io_buffer_type of GTH_229_TXRX_GTH_TX1_N   : signal is "none";
attribute io_buffer_type of GTH_229_TXRX_GTH_TX0_P   : signal is "none";
attribute io_buffer_type of GTH_229_TXRX_GTH_TX0_N   : signal is "none";
attribute io_buffer_type of GTH_228_TXRX_GTH_TX3_P   : signal is "none";
attribute io_buffer_type of GTH_228_TXRX_GTH_TX3_N   : signal is "none";
attribute io_buffer_type of GTH_228_TXRX_GTH_TX2_P   : signal is "none";
attribute io_buffer_type of GTH_228_TXRX_GTH_TX2_N   : signal is "none";
attribute io_buffer_type of GTH_228_TXRX_GTH_TX1_P   : signal is "none";
attribute io_buffer_type of GTH_228_TXRX_GTH_TX1_N   : signal is "none";
attribute io_buffer_type of GTH_228_TXRX_GTH_TX0_P   : signal is "none";
attribute io_buffer_type of GTH_228_TXRX_GTH_TX0_N   : signal is "none";
attribute io_buffer_type of GTH_227_TXRX_GTH_TX3_P   : signal is "none";
attribute io_buffer_type of GTH_227_TXRX_GTH_TX3_N   : signal is "none";
attribute io_buffer_type of GTH_227_TXRX_GTH_TX2_P   : signal is "none";
attribute io_buffer_type of GTH_227_TXRX_GTH_TX2_N   : signal is "none";
attribute io_buffer_type of GTH_227_TXRX_GTH_TX1_P   : signal is "none";
attribute io_buffer_type of GTH_227_TXRX_GTH_TX1_N   : signal is "none";
attribute io_buffer_type of GTH_227_TXRX_GTH_TX0_P   : signal is "none";
attribute io_buffer_type of GTH_227_TXRX_GTH_TX0_N   : signal is "none";
attribute io_buffer_type of GTH_226_TXRX_GTH_TX3_P   : signal is "none";
attribute io_buffer_type of GTH_226_TXRX_GTH_TX3_N   : signal is "none";
attribute io_buffer_type of GTH_226_TXRX_GTH_TX2_P   : signal is "none";
attribute io_buffer_type of GTH_226_TXRX_GTH_TX2_N   : signal is "none";
attribute io_buffer_type of GTH_226_TXRX_GTH_TX1_P   : signal is "none";
attribute io_buffer_type of GTH_226_TXRX_GTH_TX1_N   : signal is "none";
attribute io_buffer_type of GTH_226_TXRX_GTH_TX0_P   : signal is "none";
attribute io_buffer_type of GTH_226_TXRX_GTH_TX0_N   : signal is "none";
attribute io_buffer_type of GTH_225_TXRX_GTH_TX3_P   : signal is "none";
attribute io_buffer_type of GTH_225_TXRX_GTH_TX3_N   : signal is "none";
attribute io_buffer_type of GTH_225_TXRX_GTH_TX2_P   : signal is "none";
attribute io_buffer_type of GTH_225_TXRX_GTH_TX2_N   : signal is "none";
attribute io_buffer_type of GTH_225_TXRX_GTH_TX1_P   : signal is "none";
attribute io_buffer_type of GTH_225_TXRX_GTH_TX1_N   : signal is "none";
attribute io_buffer_type of GTH_225_TXRX_GTH_TX0_P   : signal is "none";
attribute io_buffer_type of GTH_225_TXRX_GTH_TX0_N   : signal is "none";
attribute io_buffer_type of GTH_224_TXRX_GTH_TX3_P   : signal is "none";
attribute io_buffer_type of GTH_224_TXRX_GTH_TX3_N   : signal is "none";
attribute io_buffer_type of GTH_224_TXRX_GTH_TX2_P   : signal is "none";
attribute io_buffer_type of GTH_224_TXRX_GTH_TX2_N   : signal is "none";
attribute io_buffer_type of GTH_224_TXRX_GTH_TX1_P   : signal is "none";
attribute io_buffer_type of GTH_224_TXRX_GTH_TX1_N   : signal is "none";
attribute io_buffer_type of GTH_224_TXRX_GTH_TX0_P   : signal is "none";
attribute io_buffer_type of GTH_224_TXRX_GTH_TX0_N   : signal is "none";
attribute io_buffer_type of GTH231_TX3_P             : signal is "none";
attribute io_buffer_type of GTH231_TX3_N             : signal is "none";
attribute io_buffer_type of GTH231_TX2_P             : signal is "none";
attribute io_buffer_type of GTH231_TX2_N             : signal is "none";
attribute io_buffer_type of GTH231_TX1_P             : signal is "none";
attribute io_buffer_type of GTH231_TX1_N             : signal is "none";
attribute io_buffer_type of GTH231_TX0_P             : signal is "none";
attribute io_buffer_type of GTH231_TX0_N             : signal is "none";
attribute io_buffer_type of DP16_DP19_TXRX_GTH_TX3_P : signal is "none";
attribute io_buffer_type of DP16_DP19_TXRX_GTH_TX3_N : signal is "none";
attribute io_buffer_type of DP16_DP19_TXRX_GTH_TX2_P : signal is "none";
attribute io_buffer_type of DP16_DP19_TXRX_GTH_TX2_N : signal is "none";
attribute io_buffer_type of DP16_DP19_TXRX_GTH_TX1_P : signal is "none";
attribute io_buffer_type of DP16_DP19_TXRX_GTH_TX1_N : signal is "none";
attribute io_buffer_type of DP16_DP19_TXRX_GTH_TX0_P : signal is "none";
attribute io_buffer_type of DP16_DP19_TXRX_GTH_TX0_N : signal is "none";
attribute io_buffer_type of DP12_DP15_TXRX_GTY_TX3_P : signal is "none";
attribute io_buffer_type of DP12_DP15_TXRX_GTY_TX3_N : signal is "none";
attribute io_buffer_type of DP12_DP15_TXRX_GTY_TX2_P : signal is "none";
attribute io_buffer_type of DP12_DP15_TXRX_GTY_TX2_N : signal is "none";
attribute io_buffer_type of DP12_DP15_TXRX_GTY_TX1_P : signal is "none";
attribute io_buffer_type of DP12_DP15_TXRX_GTY_TX1_N : signal is "none";
attribute io_buffer_type of DP12_DP15_TXRX_GTY_TX0_P : signal is "none";
attribute io_buffer_type of DP12_DP15_TXRX_GTY_TX0_N : signal is "none";
attribute io_buffer_type of DP8_DP11_TXRX_GTY_TX3_P  : signal is "none";
attribute io_buffer_type of DP8_DP11_TXRX_GTY_TX3_N  : signal is "none";
attribute io_buffer_type of DP8_DP11_TXRX_GTY_TX2_P  : signal is "none";
attribute io_buffer_type of DP8_DP11_TXRX_GTY_TX2_N  : signal is "none";
attribute io_buffer_type of DP8_DP11_TXRX_GTY_TX1_P  : signal is "none";
attribute io_buffer_type of DP8_DP11_TXRX_GTY_TX1_N  : signal is "none";
attribute io_buffer_type of DP8_DP11_TXRX_GTY_TX0_P  : signal is "none";
attribute io_buffer_type of DP8_DP11_TXRX_GTY_TX0_N  : signal is "none";
attribute io_buffer_type of DP4_DP7_TXRX_GTY_TX3_P   : signal is "none";
attribute io_buffer_type of DP4_DP7_TXRX_GTY_TX3_N   : signal is "none";
attribute io_buffer_type of DP4_DP7_TXRX_GTY_TX2_P   : signal is "none";
attribute io_buffer_type of DP4_DP7_TXRX_GTY_TX2_N   : signal is "none";
attribute io_buffer_type of DP4_DP7_TXRX_GTY_TX1_P   : signal is "none";
attribute io_buffer_type of DP4_DP7_TXRX_GTY_TX1_N   : signal is "none";
attribute io_buffer_type of DP4_DP7_TXRX_GTY_TX0_P   : signal is "none";
attribute io_buffer_type of DP4_DP7_TXRX_GTY_TX0_N   : signal is "none";
attribute io_buffer_type of DP0_DP3_TXRX_GTY_TX3_P   : signal is "none";
attribute io_buffer_type of DP0_DP3_TXRX_GTY_TX3_N   : signal is "none";
attribute io_buffer_type of DP0_DP3_TXRX_GTY_TX2_P   : signal is "none";
attribute io_buffer_type of DP0_DP3_TXRX_GTY_TX2_N   : signal is "none";
attribute io_buffer_type of DP0_DP3_TXRX_GTY_TX1_P   : signal is "none";
attribute io_buffer_type of DP0_DP3_TXRX_GTY_TX1_N   : signal is "none";
attribute io_buffer_type of DP0_DP3_TXRX_GTY_TX0_P   : signal is "none";
attribute io_buffer_type of DP0_DP3_TXRX_GTY_TX0_N   : signal is "none";
end entity WRSv4_topEntity;

